==> applet-service-2.0.0-20190923.032242-2-sources.jar: com/bizvane/appletservice/models/vo/CreateRechargeVO.java <==
package com.bizvane.appletservice.models.vo;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;

/**
 * @ClassName CreateRechargeVO
 * @DescriptTion :充值请求
 * @Auther: wd
 * @Date :2018/12/10 10:52
 */
public class CreateRechargeVO {
	/**
	 * 充值金额
	 */
	@NotNull
	// @Min(value = 1)
	private String money;
	/**
	 * 充值原因
	 */
	private String remake;
	/**
	 * 用户登录凭证
	 */
	private String code;

	/**
	 * openid
	 */
	private String openid;

	private String memberCode;

	private Long sysBrandId;
	private String appId;
	private String giveMoney;
	
	private String activityId;

	public String getMoney() {
		return money;
	}

	public void setMoney(String money) {
		this.money = money;
	}

	public String getRemake() {
		return remake;
	}

	public void setRemake(String remake) {
		this.remake = remake;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getOpenid() {
		return openid;
	}

	public void setOpenid(String openid) {
		this.openid = openid;
	}

	public String getMemberCode() {
		return memberCode;
	}

	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode;
	}

	public Long getSysBrandId() {
		return sysBrandId;
	}

	public void setSysBrandId(Long sysBrandId) {
		this.sysBrandId = sysBrandId;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getGiveMoney() {
		return giveMoney;
	}

	public void setGiveMoney(String giveMoney) {
		this.giveMoney = giveMoney;
	}

	@Override
	public String toString() {
		return "CreateRechargeVO{" + "money='" + money + '\'' + ", remake='" + remake + '\'' + ", code='" + code + '\''
				+ ", openid='" + openid + '\'' + ", memberCode='" + memberCode + '\'' + ", sysBrandId=" + sysBrandId
				+ ", appId='" + appId + '\'' + ", giveMoney='" + giveMoney + '\'' + '}';
	}

	public String getActivityId() {
		return activityId;
	}

	public void setActivityId(String activityId) {
		this.activityId = activityId;
	}
}

==> applet-service-2.0.0-20200115.062433-3-sources.jar: com/bizvane/appletservice/models/vo/CreateRechargeVO.java <==
package com.bizvane.appletservice.models.vo;

import io.swagger.annotations.ApiModelProperty;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotNull;

/**
 * @ClassName CreateRechargeVO
 * @DescriptTion :充值请求
 * @Auther: wd
 * @Date :2018/12/10 10:52
 */
public class CreateRechargeVO {
	/**
	 * 充值金额
	 */
	@NotNull
	// @Min(value = 1)
	private String money;
	/**
	 * 充值原因
	 */
	private String remake;
	/**
	 * 用户登录凭证
	 */
	private String code;

	/**
	 * openid
	 */
	private String openid;

	private String memberCode;

	private Long sysBrandId;
	private String appId;
	private String giveMoney;
	
	private String activityId;

	@ApiModelProperty(value = "ur储蓄卡卡面code")
	private String cardStyleCode;

	@ApiModelProperty(value = "ur储蓄名称")
	private String name;

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getCardStyleCode() {
		return cardStyleCode;
	}

	public void setCardStyleCode(String cardStyleCode) {
		this.cardStyleCode = cardStyleCode;
	}

	public String getMoney() {
		return money;
	}

	public void setMoney(String money) {
		this.money = money;
	}

	public String getRemake() {
		return remake;
	}

	public void setRemake(String remake) {
		this.remake = remake;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getOpenid() {
		return openid;
	}

	public void setOpenid(String openid) {
		this.openid = openid;
	}

	public String getMemberCode() {
		return memberCode;
	}

	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode;
	}

	public Long getSysBrandId() {
		return sysBrandId;
	}

	public void setSysBrandId(Long sysBrandId) {
		this.sysBrandId = sysBrandId;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getGiveMoney() {
		return giveMoney;
	}

	public void setGiveMoney(String giveMoney) {
		this.giveMoney = giveMoney;
	}

	@Override
	public String toString() {
		return "CreateRechargeVO{" +
				"money='" + money + '\'' +
				", remake='" + remake + '\'' +
				", code='" + code + '\'' +
				", openid='" + openid + '\'' +
				", memberCode='" + memberCode + '\'' +
				", sysBrandId=" + sysBrandId +
				", appId='" + appId + '\'' +
				", giveMoney='" + giveMoney + '\'' +
				", activityId='" + activityId + '\'' +
				", cardStyleCode='" + cardStyleCode + '\'' +
				", name='" + name + '\'' +
				'}';
	}

	public String getActivityId() {
		return activityId;
	}

	public void setActivityId(String activityId) {
		this.activityId = activityId;
	}
}
